@@ -11,7 +11,7 @@ def compute_args():
     check args and return them
     """
     my_parser = argparse.ArgumentParser(
-        description="pyvitemadose affiche les chronodoses disponibles du departement en parametre",
+        description="pyvitemadose displays available chronodoses of covid vaccine for your departement in France given in parameter",
         epilog="""
         Full documentation at: <https://github.com/thib1984/pyvitemadose>.
         Report bugs to <https://github.com/thib1984/pyvitemadose/issues>.
@@ -21,12 +21,20 @@ def compute_args():
         There is NO WARRANTY, to the extent permitted by law.
         Written by thib1984.""",
     )
-    my_parser.add_argument(
+    my_group = my_parser.add_mutually_exclusive_group(required=True)
+    my_group.add_argument(
         "departement",
         metavar="departement",
-        type=int,
+        type=str,
+        nargs="?",
         help="numero departement",
     )
+    my_group.add_argument(
+        "-u",
+        "--update",
+        action="store_true",
+        help="update pyvitemadose",
+    )
 
     # if no parameter
     if len(sys.argv) == 1:
