@@ -1,5 +1,5 @@
 """
-pyvitemadose argparse gestion
+pyvitemadose use case
 """
 
 import argparse
@@ -8,17 +8,19 @@ import requests
 
 def find(dept):
     trouve = False
-    r = requests.get("https://vitemadose.gitlab.io/vitemadose/"+str(dept)+".json")
-    centres_disponibles = r.json().get("centres_disponibles",[])
-    for centre in centres_disponibles:
-        appointment_schedules =  centre.get("appointment_schedules",[])
-        for schedule in appointment_schedules:
+    r = requests.get("https://vitemadose.gitlab.io/vitemadose/"+dept.zfill(2)+".json")
+    if str(r) != "<Response [200]>":
+        print("no data found, verify the departement")
+        sys.exit(1)
+    for centre in r.json().get("centres_disponibles",[]):
+        for schedule in  centre.get("appointment_schedules",[]):
             if schedule.get("name","") == "chronodose" and schedule.get("total","") != 0:
                 trouve = True
                 print("url      : " + centre.get("url"))
                 print("adresse  : " + centre.get("metadata").get("address"))
                 print("type     : " + str(centre.get("vaccine_type")))
                 print("doses    : " + str(schedule.get("total")))    
-                print("")           
+                print("")                           
     if not trouve:
-        print("pas de creneaux trouves...")            
\ No newline at end of file
+        print("pas de creneaux trouves...")
+        sys.exit(2)
\ No newline at end of file
